# Smaller Folders
Split an arbitrary number of files into sub-folders containing a specified number of files each.

Turning
```
folder
├── file001
│   ...
└── file100
```
into
```
folder
├── sub_folder001
│   ├── file001
│   │   ...
│   └── file010
├── sub_folder002
│   ...
```
